============================================================================
Générateur de Graphe d'État Asynchrone. 
============================================================================

***************************************
(Asynchronous State Graph Generator)
***************************************

.. image:: https://travis-matrix-badges.herokuapp.com/repos/clement-alexandre/TotemBionet/branches/master/1
    :target: https://travis-ci.com/clement-alexandre/TotemBionet


Installation
---------------

Install with `pip <https://pypi.org/project/ggea/>`_:

    `pip install ggea`

Install with `conda <https://anaconda.org/alexandre-clement/ggea>`_:

    `conda install -c alexandre-clement ggea`


Run tests
---------

Execute the following command to run the test suite:
    
    `python -m unittest tests.test`


Contributors
------------

Gabriel Flores-Lipa (gabriel.flores-lipa@etu.unice.fr)